import { getHomeUserSchedule } from '../../api/request.js'
import { throttle } from './../../utils/utils.js'
import create from 'dd-store'
import exampleStore from '/stores/exampleStore'
create.Page({
  store: exampleStore,
  useAll: true,
  data: {
    // 传给组件list 的所有数据 comListData
    comListData: {
      repeatList: [
        { id: 0, text: '不重复', icon: 'iconicon_cycle', repeatable: 0, recurrenceModel: { model: 'no_repeat' } },
        { id: 1, text: '每天', icon: '', repeatable: 1, recurrenceModel: { model: 'daily', interval: 1, initialTime: null, terminateTime: null, weekDayList: null } },
        { id: 2, text: '每周', icon: '', repeatable: 1, recurrenceModel: { model: 'weekly', interval: 1, initialTime: null, terminateTime: null, weekDayList: null } },
        { id: 3, text: '每周的工作日', icon: '', repeatable: 1, recurrenceModel: { model: 'weekly', interval: 1, initialTime: null, terminateTime: null, weekDayList: ['MO', 'TU', 'WE', 'TH', 'FR', 'SA'] } },
        { id: 4, text: '每月', icon: '', repeatable: 1, recurrenceModel: { model: 'absoluteMonthly', interval: 1, initialTime: null, terminateTime: null, weekDayList: null } },
        { id: 5, text: '每年', icon: '', repeatable: 1, recurrenceModel: { model: 'absoluteYearly', interval: 1, initialTime: null, terminateTime: null, weekDayList: null } }
      ],
      meetingWayList: [
        { id: 0, text: 'Webex meeting', imageUrl: '../../assests/Webex.png' },
        { id: 1, text: 'Zoom Meeting', imageUrl: '../../assests/Zoom.png' },
        { id: 2, text: '钉钉', imageUrl: '../../assests/dingding.png' }
      ],
      comSelectListId: 0,
      meetingWayModelId: null,
      iconType: 'icon'
    },
    // 传给组件 hList 水平排列  所有数据 comHListData
    comHListData: {
      contactData: [
        { id: 0, text: '钉钉联系人', imageUrl: '../../assests/dingContact.png' },
        { id: 1, text: '手动添加邮箱', imageUrl: '../../assests/emailContact.png' }
      ]
    },
    show: true,
    title: '',
    repeatable: '',
    recurrenceModel: '',
    isShowRemark: false,
    repeatWeek: ['SU', 'MO', 'TU', 'WE', 'TH', 'FR', 'SA'],
    popupTitle: '会议重复',
    popupShow: false,
    comType: '',
    remark: '',
    comTimeType: ''
  },
  showPop() {
    this.setData({
      show: true
    })
  },
  closePop() {
    this.setData({
      show: false
    })
  },
  Complete(data) {
    console.log(data)
    this.closePop();
  },
  onLoad() {
    dd.setNavigationBar({
      title: '创建会议'
    })
    this.reset()
  },
  // 添加描述
  addRemark() {
    let isShowRemark = !this.data.isShowRemark
    if (!isShowRemark) {
      this.setData({
        remark: ''
      })
    }
    this.setData({
      isShowRemark: isShowRemark
    })
    this.update()

  },
  // 输入框输入事件
  onInput(event) {
    switch (event.target.dataset.type) {
      case 'title':
        this.setData({
          title: event.detail.value
        })
        break
      case 'remark':
        this.setData({
          remark: event.detail.value
        })
        break
    }
  },
  // 初始化
  reset() {
    this.store.data.roomId = ''
    this.store.data.locationName = ''
    this.update()
  },
  // 跳转下一页
  nextPage(event) {
    switch (event.target.dataset.nextPage) {
      case 'location':
        this.store.data.startTime = '2020/03/18 16:00:00'
        this.store.data.endTime = '2020/03/18 16:00:00'
        this.update()
        dd.navigateTo({ url: './../place/place' })
        break
    }
  },
  // 所有的关闭操作
  close(event) {
    switch (event.target.dataset.close) {
      case 'location':
        this.store.data.locationName = ''
        this.store.data.roomId = ''
        this.update()
        break
      case 'meetingWayModel':
        this.setData({
          'comListData.meetingWayModelId': null
        })
    }
  },
  // 关闭popup 点击mark
  closePopup() {
    this.setData({
      popupShow: false
    })
  },
  // 选择循环机制 选择会议方式  出现popup弹窗
  showPopup(event) {
    let iconType = ''
    switch (event.currentTarget.dataset.type) {
      case 'meetingWayModel':
        iconType = 'image'
        break
      case 'repeat':
        iconType = 'icon'
        break
      case 'participator':
        break
      case 'time':
        // this.setData({
        //   comTimeType: true
        // })
        break
    }
    this.setData({
      popupShow: true,
      comType: event.currentTarget.dataset.type,
      'comListData.iconType': iconType
    })
  },
  // 选择完comList后的回调
  selectComList(event) {
    switch (this.data.comType) {
      case 'meetingWayModel':
        this.setData({
          'comListData.meetingWayModelId': event.currentTarget.dataset.item.id,
          popupShow: false
        })
        break;
      case 'repeat':
        let initialTime = '2020/03/18 16:00:00'
        let terminateTime = this.getTwoYearToday(initialTime)
        for (let value of this.data.comListData.repeatList) {
          if (value.recurrenceModel.model !== 'no_repeat') {
            value.recurrenceModel.initialTime = initialTime.replace(/\//g, "-").substring(0, 10)
            value.recurrenceModel.terminateTime = terminateTime
          }
        }
        let repeatList = this.data.comListData.repeatList
        repeatList[2].recurrenceModel.weekDayList = ['MO']
        this.setData({
          repeatList: repeatList
        }, () => {
          this.setData({
            popupShow: false,
            'comListData.comSelectListId': event.currentTarget.dataset.item.id,
            repeatable: event.currentTarget.dataset.item.repeatable,
            recurrenceModel: event.currentTarget.dataset.item.recurrenceModel
          })
        })
        break;
    }
  },
  // 选择完水平 HList 的回调
  selectComHList(event) {
    console.log(event)
    switch (event.currentTarget.dataset.item.id) {
      case 0:
        this.addParticipator()
        this.setData({
          popupShow: false
        })
        break;
      case 1:
        this.setData({
          popupShow: false
        })
        dd.navigateTo({ url: './../outLookContact/outLookContact' })
        break;
    }
  },
  // 获取两年后的今天
  getTwoYearToday(startTime) {
    let date = new Date(startTime)
    date.setYear(date.getFullYear() + 2)
    let year = date.getFullYear();
    let month = date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1;
    let day = date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
    return year + '-' + month + '-' + day
  },
  // 添加参会人
  addParticipator() {
    const _that = this
    let require = []
    let select = []
    select = this.store.data.participatorUserId
    require = [getApp().globalData.userid]
    select = _that.selectedelRequired(require, select).pickedUsers
    dd.complexChoose({
      title: "选择参会人",            //标题
      multiple: true,            //是否多选
      pickedUsers: select, //已选用户
      requiredUsers: require,            //必选用户（不可取消选中状态）
      responseUserOnly: true,        //返回人，或者返回人和部门
      success: function (res) {
        _that.store.data.participatorList = []
        _that.store.data.participatorUserId = []
        _that.store.data.participatorList.push({ userId: getApp().globalData.userid, username: getApp().globalData.name, headUrl: getApp().globalData.avatar, platform: 'dingtalk' })
        _that.store.data.participatorUserId.push(getApp().globalData.userid)
        res.users.forEach((item, index) => {
          _that.store.data.participatorList.push({ userId: item.userId, username: item.name, headUrl: item.avatar, platform: 'dingtalk' })
          _that.store.data.participatorUserId.push(item.userId)
        })
        _that.store.data.participatorList = _that.setArrary(_that.store.data.participatorList)
        _that.store.data.participatorUserId = [...new Set(_that.store.data.participatorUserId)]
        _that.update()
      },
      fail: function (err) {
      }
    })
  },
  // 已选用户去中去掉必选用户
  selectedelRequired(req, pic) {
    for (let i = 0; i < req.length; i++) {
      for (let m = 0; m < pic.length; m++) {
        if (req[i] == pic[m]) {
          pic.splice(m, 1)
          m--;
        }
      }
    }
    return {
      requiredUsers: req,
      pickedUsers: pic
    }
  },
  // 数组 去重
  setArrary(arr) {
    let containt = {}
    for (let x of arr) {
      containt['id' + x.userId] = x
    }
    return Object.values(containt)
  },
});
